abacusai.feature_group_template_variable_options — AbacusAI documentation

# abacusai.feature_group_template_variable_options

## Classes

`FeatureGroupTemplateVariableOptions` | Feature Group Template Variable Options

## Module Contents

class abacusai.feature_group_template_variable_options.FeatureGroupTemplateVariableOptions(client, templateVariableOptions=None, userFeedback=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Feature Group Template Variable Options

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - templateVariableOptions (list[dict]) – List of values we can select for different template variables.

    - userFeedback (list[str]) – List of additional information regarding variable options for the user.

  template_variable_options
  user_feedback
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict